library ieee;
use ieee.std_logic_1164.all;

library work;
use work.pk_hex27seg.all;
use work.pk_counter.all;


entity top is
  port(
    -- inputs
    SW : in std_logic_vector(9 downto 0);     -- switches
    KEY: in std_logic_vector(2 downto 0);     -- push buttons

    -- -- 7 segment displays
    HEX0: out std_logic_vector(7 downto 0);  
    HEX1: out std_logic_vector(7 downto 0);
--    HEX2: out std_logic_vector(7 downto 0);
    HEX3: out std_logic_vector(7 downto 0)
    );
end top;      


architecture arch of top is
  signal s_clk: std_logic;
  signal s_address: std_logic_vector(3 downto 0);
  signal s_data: std_logic_vector(7 downto 0);
  signal s_q: std_logic_vector(7 downto 0);
  
  component ramwiz IS
	PORT
	(
		address		: IN STD_LOGIC_VECTOR (3 DOWNTO 0);
		clock		: IN STD_LOGIC ;
		data		: IN STD_LOGIC_VECTOR (7 DOWNTO 0);
		wren		: IN STD_LOGIC ;
		q		: OUT STD_LOGIC_VECTOR (7 DOWNTO 0)
	);
END component;
  
begin
  
address_counter: counter port map (clk => s_clk, 
                                   clear => '0', enable => '1',
                                   count => s_address);

-- ram0 : ram port map ();
ram_inst : ramwiz PORT MAP (
		address	 => s_address,
		clock	 => s_clk,
		data	 => s_data,
		wren	 => SW(9),
		q	 => s_q
	);

s_data <= SW(7 downto 0);

-- Hex to 7-segment decoders
address_hex: hex27seg port map (hex_in => s_address, seg_out => HEX3(6 downto 0));
data_hi_hex: hex27seg port map (hex_in => s_q(7 downto 4), seg_out => HEX1(6 downto 0));
data_lo_hex: hex27seg port map (hex_in => s_q(3 downto 0), seg_out => HEX0 (6 downto 0));

-- clk is the output of a SR latch controlled by KEY1, KEY2
SR: process (KEY(2), KEY(1))
begin
  if KEY(2) = '0' then                  -- set
    s_clk <= '1';
  elsif KEY(1) = '0' then               -- reset
    s_clk <= '0';
  end if;
end process;

end architecture; 
